### 0.10.6 {small}`2024-06-25`

```{rubric} Bug fixes
```
 * removes `.A` to be compatible with scipy 1.14.0 {pr}`214` {smaller}`S Dicks`

```{rubric} Misc
```
* updates tests to work without `scanpy.testing` {pr}`215` {smaller}`S Dicks`
